<?php

if (!defined('WEBTOTEM_INIT') || WEBTOTEM_INIT !== true) {
	if (!headers_sent()) {
		header('HTTP/1.1 403 Forbidden');
	}
	die("Protected By WebTotem!");
}

if (defined('WEBTOTEM')) {

	/**
	 * Plugin's session start.
	 */
	if(!session_id()) {
		session_start();
	}

	/**
	 * Plugin's session close.
	 */
	function wtotem_curl_before_request($curlhandle){
		session_write_close();
	}
	add_action( 'requests-curl.before_request','wtotem_curl_before_request', 9999 );

  /**
   * Remove the WordPress generator meta-tag from the source code.
   */
  remove_action('wp_head', 'wp_generator');

  /**
   * Define which javascript and css files will be loaded in the header of the
   * plugin pages.
   */
  add_action('admin_enqueue_scripts', 'WebTotemInterface::enqueueScripts', 1);

	/* Execute pre-checks before every page */
	add_action('wp_loaded', 'WebTotemInterface::startupChecks');

	add_action( 'wp_insert_site', 'WebTotemInterface::addNewSite' );


	/* Attach HTTP request handlers for the AJAX requests */
	add_action('wp_ajax_wtotem_ajax', 'wtotem_ajax_callback');

  /**
   * List an associative array with the sub-pages of this plugin.
   *
   * @return array List of sub-pages of this plugin.
   */
  function wtotemPages() {
	  if( WebTotem::isMultiSite() ) {
		  $pages['wtotem_all_sites'] = [ 'title' =>  __('All sites', 'wtotem'), 'slug' => 'wtotem'];
	  }
		$slug = WebTotem::isMultiSite() ? 'wtotem_' : 'wtotem';

	  $pages['wtotem_dashboard'] = [ 'title' =>  __('Dashboard', 'wtotem'), 'slug' => $slug];
	  $pages['wtotem_firewall']  = [ 'title' =>  __('Firewall', 'wtotem'), 'slug' => $slug];
	  if(!WebTotem::isMultiSite() or is_super_admin()) {
		  $pages['wtotem_antivirus'] = [ 'title' =>  __('Antivirus', 'wtotem'), 'slug' => $slug];
		  $pages['wtotem_settings']  = [ 'title' =>  __('Settings', 'wtotem'), 'slug' => $slug];
	  }
	  $pages['wtotem_reports']   = [ 'title' =>  __('Reports', 'wtotem'), 'slug' => $slug];
	  $pages['wtotem_documentation'] = [ 'title' =>  __('Documentation', 'wtotem'), 'slug' => 'wtotem'];

    return $pages;
  }

  if (function_exists('add_action')) {
      /**
       * Display extension menu and submenu items in the correct interface.
       *
       * @return void
       */
      function wtotemAddMenu() {

	      $page = ! WebTotemOption::isActivated() ? 'activation' : ( WebTotem::isMultiSite() ? 'all_sites' : 'dashboard' );

        add_menu_page(
            __('WebTotem Security', 'wtotem'),
            __('WebTotem Security', 'wtotem'),
            'manage_options',
            'wtotem',
            'wtotem_' . $page . '_page',
            WebTotem::getImagePath('logo_17x17_w.png')
        );

        if(WebTotemOption::isActivated()){
	        $pages = wtotemPages();
          foreach ($pages as $sub_page_function => $sub_page) {
              add_submenu_page(
	              $sub_page['slug'],
	              $sub_page['title'],
	              $sub_page['title'],
	              'manage_options',
                $sub_page_function,
                $sub_page_function . '_page'
              );
          }

        } else {
	        add_submenu_page(
		        'wtotem',
		        __('Activation', 'wtotem'),
		        __('Activation', 'wtotem'),
		        'manage_options',
		        'wtotem_activation',
		        'wtotem_activation_page'
	        );
        }
      }

      /* Attach HTTP request handlers for the internal plugin pages */
	    if(WebTotem::isMultiSite()){
		    add_action('network_admin_menu', 'wtotemAddMenu');
	    }
	    add_action('admin_menu', 'wtotemAddMenu');

  }

}
